/* ***** BEGIN LICENSE BLOCK *****
 *   Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Flash Killer.
 *
 * The Initial Developer of the Original Code is
 * Nicolas Martin <joliclic@gmail.com>.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Adam Nellis <adam.nellis@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */

var flashKiller = {
	init: function flashKiller_init() {
		if (!flashKiller.prefObserver.prefs.getBoolPref("contextmenu")) {
			document.getElementById("context-flashkiller").hidden = true;
		}
		if (!flashKiller.prefObserver.prefs.getBoolPref("toolmenu")) {
			document.getElementById("flashkiller-tool").hidden = true;
		}
		if (!flashKiller.prefObserver.prefs.getBoolPref("statusbar")) {
			document.getElementById("flashkiller-statusbar").hidden = true;
		}
		
		flashKiller.prefObserver.startup();
	},
	
	uninit: function flashkiller_uninit() {
		flashKiller.prefObserver.shutdown();
	},
	
	flashPluginEnabled: function flashKiller_flashPluginEnabled() {
		if (navigator.mimeTypes
		    && navigator.mimeTypes.length
		    && navigator.mimeTypes["application/x-shockwave-flash"]
		    && navigator.mimeTypes["application/x-shockwave-flash"].enabledPlugin)
			return true;
		else
			return false;
	},
	
	killAll: function flashKiller_killAll(aDoc) {
		if (!this.flashPluginEnabled())
			return;
		
		var embs = aDoc.getElementsByTagName("embed");
		for (var i = embs.length-1; i >= 0; i--) {
			var emb = embs[i];
			if (emb.type && emb.type == "application/x-shockwave-flash") {
				if (emb.parentNode
				    && emb.parentNode.tagName
				    && emb.parentNode.tagName.toLowerCase == "object") {
					this.replaceFlashElt(emb.parentNode);
				} else {
					this.replaceFlashElt(emb);
				}
			}
		}
		
		var objs = aDoc.getElementsByTagName("object");
		for (var i = objs.length-1; i >= 0; i--) {
			var obj = objs[i];
			if (obj.type && obj.type == "application/x-shockwave-flash") {
				this.replaceFlashElt(obj);
			}
		}
		
		
		// treat all sub documents
		
		//frames
		var frames = aDoc.getElementsByTagName("frame");
		for (i = 0; i < frames.length; i++) {
			this.killAll(frames[i].contentDocument);
		}
		
		//iframes
		var iframes = aDoc.getElementsByTagName("iframe");
		for (i = 0; i < iframes.length; i++) {
			this.killAll(iframes[i].contentDocument);
		}
		
		//object type text/html
		var objHtmls = aDoc.getElementsByTagName("object");
		for (var i = 0; i < objHtmls.length; i++) {
			var obj = objHtmls[i];
			if (objs[i].contentDocument) {
				this.killAll(objs[i].contentDocument);
			}
		}
	},
	
	replaceFlashElt: function flashKiller_replaceFlashElt(aElt) {
		var div = aElt.ownerDocument.createElement("div");
		
		var styles = aElt.ownerDocument.defaultView.getComputedStyle(aElt, null);
		
		div.style.width = styles.width;
		div.style.height = styles.height;
		div.style.border = "1px blue dashed";
		div.style.background = "url('chrome://flashkiller-public/skin/flash-bg.png') repeat";
		// -moz-box-sizing: content-box;
		div.style.MozBoxSizing = "border-box";
		
		
		aElt.parentNode.replaceChild(div, aElt);
	},
	
	prefObserver: {
		prefs: Cc["@mozilla.org/preferences-service;1"]
		       .getService(Ci.nsIPrefService)
		       .getBranch("extensions.flashkiller."),
		
		startup: function flashKillerPO_startup() {
			this.prefs.QueryInterface(Ci.nsIPrefBranch2);
			this.prefs.addObserver("", this, false);
		},
		
		shutdown: function flashKillerPO_shutdown() {
			this.prefs.removeObserver("", this);
		},
		
		observe: function flashKillerPO_observe(subject, topic, data) {
			if (topic != "nsPref:changed")
				return;
			
			switch(data) {
				case "contextmenu":
					if (this.prefs.getBoolPref("contextmenu"))
						document.getElementById("context-flashkiller").hidden = false;
					else
						document.getElementById("context-flashkiller").hidden = true;
					break;
				case "toolmenu":
					if (this.prefs.getBoolPref("toolmenu"))
						document.getElementById("flashkiller-tool").hidden = false;
					else {
						document.getElementById("flashkiller-tool").hidden = true;
					}
					break;
				case "statusbar":
					if (this.prefs.getBoolPref("statusbar"))
						document.getElementById("flashkiller-statusbar").hidden = false;
					else 
						document.getElementById("flashkiller-statusbar").hidden = true;
					break;
			}
		}
	}
};

window.addEventListener("load", flashKiller.init, false);
window.addEventListener("unload", flashKiller.uninit, false);

